==> orionis-0.532.0.tar.gz: orionis-0.532.0/orionis/foundation/providers/console_provider.py <==
from orionis.console.output.console import Console
from orionis.console.output.contracts.console import IConsole
from orionis.container.providers.service_provider import ServiceProvider

class ConsoleProvider(ServiceProvider):
    """
    Console output service provider for the Orionis framework.

    This service provider is responsible for registering and configuring the console
    output service within the application's dependency injection container. It binds
    the IConsole interface to its concrete Console implementation, enabling the
    application to access comprehensive console output functionality including
    informational messages, warnings, errors, debug output, tabular data display,
    user confirmations, and secure password input prompts.

    The provider follows the standard service provider pattern, implementing both
    registration and boot phases for proper initialization within the application
    lifecycle.
    """

    def register(self) -> None:
        """
        Register the console output service in the application's dependency injection container.

        This method binds the IConsole interface to its concrete Console implementation,
        making console output functionality available throughout the application. The
        service is registered as a transient dependency, meaning a new instance will
        be created each time it is requested from the container.

        The registration uses a predefined alias to ensure consistent service
        identification across the framework and facilitate easy service resolution.

        Returns
        -------
        None
            This method does not return any value. It performs side effects by
            modifying the application's service container.
        """

        self.app.transient(IConsole, Console, alias="x-orionis.console.output.console")

    def boot(self) -> None:
        """
        Perform post-registration initialization for the console provider.

        This method is called after the registration phase is complete and all services
        have been registered in the container. It provides an opportunity to perform
        any additional setup, configuration, or initialization that depends on other
        services being available in the container.

        Currently, this implementation serves as a placeholder and does not perform
        any specific initialization tasks. The console service is fully functional
        after registration and does not require additional boot-time configuration.

        This method is part of the service provider lifecycle and is automatically
        invoked by the framework during application startup.

        Returns
        -------
        None
            This method does not return any value and is called for its side effects
            during the service provider boot phase.
        """

        pass

==> orionis-0.577.0.tar.gz: orionis-0.577.0/orionis/foundation/providers/console_provider.py <==
from orionis.console.output.console import Console
from orionis.console.contracts.console import IConsole
from orionis.container.providers.service_provider import ServiceProvider

class ConsoleProvider(ServiceProvider):
    """
    Console output service provider for the Orionis framework.

    This service provider is responsible for registering and configuring the console
    output service within the application's dependency injection container. It binds
    the IConsole interface to its concrete Console implementation, enabling the
    application to access comprehensive console output functionality including
    informational messages, warnings, errors, debug output, tabular data display,
    user confirmations, and secure password input prompts.

    The provider follows the standard service provider pattern, implementing both
    registration and boot phases for proper initialization within the application
    lifecycle.
    """

    def register(self) -> None:
        """
        Register the console output service in the application's dependency injection container.

        This method binds the IConsole interface to its concrete Console implementation,
        making console output functionality available throughout the application. The
        service is registered as a transient dependency, meaning a new instance will
        be created each time it is requested from the container.

        The registration uses a predefined alias to ensure consistent service
        identification across the framework and facilitate easy service resolution.

        Returns
        -------
        None
            This method does not return any value. It performs side effects by
            modifying the application's service container.
        """

        self.app.transient(IConsole, Console, alias="x-orionis.console.output.console")

    def boot(self) -> None:
        """
        Perform post-registration initialization for the console provider.

        This method is called after the registration phase is complete and all services
        have been registered in the container. It provides an opportunity to perform
        any additional setup, configuration, or initialization that depends on other
        services being available in the container.

        Currently, this implementation serves as a placeholder and does not perform
        any specific initialization tasks. The console service is fully functional
        after registration and does not require additional boot-time configuration.

        This method is part of the service provider lifecycle and is automatically
        invoked by the framework during application startup.

        Returns
        -------
        None
            This method does not return any value and is called for its side effects
            during the service provider boot phase.
        """

        pass
